[Bf-blender-cvs] [beaf2baeffc] master: Cleanup: fix wrong spelling of texture and indentation

Brecht Van Lommel noreply at git.blender.org
Wed Mar 9 15:16:04 CET 2022


Commit: beaf2baeffc9a15eba53a61460573948319fecf4
Author: Brecht Van Lommel
Date:   Wed Mar 9 15:02:04 2022 +0100
Branches: master
https://developer.blender.org/rBbeaf2baeffc9a15eba53a61460573948319fecf4

Cleanup: fix wrong spelling of texture and indentation

Contributed by luzpaz.

Ref D14271, D14270

===================================================================

M	source/blender/blenkernel/intern/fluid.c
M	source/blender/blenkernel/intern/linestyle.c
M	source/blender/editors/animation/anim_channels_defines.c
M	source/blender/editors/animation/anim_channels_edit.c
M	source/blender/editors/include/ED_anim_api.h
M	source/blender/python/gpu/gpu_py_texture.c

===================================================================

diff --git a/source/blender/blenkernel/intern/fluid.c b/source/blender/blenkernel/intern/fluid.c
index f85361e94ff..ca9d758c692 100644
--- a/source/blender/blenkernel/intern/fluid.c
+++ b/source/blender/blenkernel/intern/fluid.c
@@ -1937,7 +1937,7 @@ static void sample_mesh(FluidFlowSettings *ffs,
 
           interp_v2_v2v2v2(tex_co, UNPACK3(uv), weights);
 
-          /* Map texure coord between -1.0f and 1.0f. */
+          /* Map texture coord between -1.0f and 1.0f. */
           tex_co[0] = tex_co[0] * 2.0f - 1.0f;
           tex_co[1] = tex_co[1] * 2.0f - 1.0f;
           tex_co[2] = ffs->texture_offset;
diff --git a/source/blender/blenkernel/intern/linestyle.c b/source/blender/blenkernel/intern/linestyle.c
index e50d6263423..bbcc886f3ff 100644
--- a/source/blender/blenkernel/intern/linestyle.c
+++ b/source/blender/blenkernel/intern/linestyle.c
@@ -2035,7 +2035,7 @@ bool BKE_linestyle_use_textures(FreestyleLineStyle *linestyle, const bool use_sh
 
 void BKE_linestyle_default_shader(const bContext *C, FreestyleLineStyle *linestyle)
 {
-  bNode *uv_along_stroke, *input_texure, *output_linestyle;
+  bNode *uv_along_stroke, *input_texture, *output_linestyle;
   bNodeSocket *fromsock, *tosock;
   bNodeTree *ntree;
 
@@ -2050,9 +2050,9 @@ void BKE_linestyle_default_shader(const bContext *C, FreestyleLineStyle *linesty
   uv_along_stroke->locy = 300.0f;
   uv_along_stroke->custom1 = 0; /* use_tips */
 
-  input_texure = nodeAddStaticNode(C, ntree, SH_NODE_TEX_IMAGE);
-  input_texure->locx = 200.0f;
-  input_texure->locy = 300.0f;
+  input_texture = nodeAddStaticNode(C, ntree, SH_NODE_TEX_IMAGE);
+  input_texture->locx = 200.0f;
+  input_texture->locy = 300.0f;
 
   output_linestyle = nodeAddStaticNode(C, ntree, SH_NODE_OUTPUT_LINESTYLE);
   output_linestyle->locx = 400.0f;
@@ -2060,15 +2060,15 @@ void BKE_linestyle_default_shader(const bContext *C, FreestyleLineStyle *linesty
   output_linestyle->custom1 = MA_RAMP_BLEND;
   output_linestyle->custom2 = 0; /* use_clamp */
 
-  nodeSetActive(ntree, input_texure);
+  nodeSetActive(ntree, input_texture);
 
   fromsock = BLI_findlink(&uv_along_stroke->outputs, 0); /* UV */
-  tosock = BLI_findlink(&input_texure->inputs, 0);       /* UV */
-  nodeAddLink(ntree, uv_along_stroke, fromsock, input_texure, tosock);
+  tosock = BLI_findlink(&input_texture->inputs, 0);      /* UV */
+  nodeAddLink(ntree, uv_along_stroke, fromsock, input_texture, tosock);
 
-  fromsock = BLI_findlink(&input_texure->outputs, 0);  /* Color */
+  fromsock = BLI_findlink(&input_texture->outputs, 0); /* Color */
   tosock = BLI_findlink(&output_linestyle->inputs, 0); /* Color */
-  nodeAddLink(ntree, input_texure, fromsock, output_linestyle, tosock);
+  nodeAddLink(ntree, input_texture, fromsock, output_linestyle, tosock);
 
   BKE_ntree_update_main_tree(CTX_data_main(C), ntree, NULL);
 }
diff --git a/source/blender/editors/animation/anim_channels_defines.c b/source/blender/editors/animation/anim_channels_defines.c
index edb6d188ab8..f4412ea837d 100644
--- a/source/blender/editors/animation/anim_channels_defines.c
+++ b/source/blender/editors/animation/anim_channels_defines.c
@@ -203,7 +203,7 @@ static void acf_generic_channel_color(bAnimContext *ac, bAnimListElem *ale, floa
     rgb_uchar_to_float(r_color, cp);
   }
   else {
     /* FIXME: what happens when the indention is 1 greater than what it should be
      * (due to grouping)? */
     int colOfs = 10 - 10 * indent;
     UI_GetThemeColorShade3fv(TH_SHADE2, colOfs, r_color);
@@ -252,44 +252,44 @@ static void acf_generic_channel_backdrop(bAnimContext *ac,
   immUnbindProgram();
 }
 
-/* Indention + Offset ------------------------------------------- */
+/* Indentation + Offset ------------------------------------------- */
 
-/* indention level is always the value in the name */
-static short acf_generic_indention_0(bAnimContext *UNUSED(ac), bAnimListElem *UNUSED(ale))
+/* indentation level is always the value in the name */
+static short acf_generic_indentation_0(bAnimContext *UNUSED(ac), bAnimListElem *UNUSED(ale))
 {
   return 0;
 }
-static short acf_generic_indention_1(bAnimContext *UNUSED(ac), bAnimListElem *UNUSED(ale))
+static short acf_generic_indentation_1(bAnimContext *UNUSED(ac), bAnimListElem *UNUSED(ale))
 {
   return 1;
 }
 #if 0 /* XXX not used */
-static short acf_generic_indention_2(bAnimContext *ac, bAnimListElem *ale)
+static short acf_generic_indentation_2(bAnimContext *ac, bAnimListElem *ale)
 {
   return 2;
 }
 #endif
 
-/* indention which varies with the grouping status */
-static short acf_generic_indention_flexible(bAnimContext *UNUSED(ac), bAnimListElem *ale)
+/* indentation which varies with the grouping status */
+static short acf_generic_indentation_flexible(bAnimContext *UNUSED(ac), bAnimListElem *ale)
 {
   short indent = 0;
 
   /* grouped F-Curves need extra level of indention */
   if (ale->type == ANIMTYPE_FCURVE) {
     FCurve *fcu = (FCurve *)ale->data;
 
     /* TODO: we need some way of specifying that the indention color should be one less. */
     if (fcu->grp) {
       indent++;
     }
   }
 
-  /* no indention */
+  /* no indentation */
   return indent;
 }
 
 /* basic offset for channels derived from indention */
 static short acf_generic_basic_offset(bAnimContext *ac, bAnimListElem *ale)
 {
   const bAnimChannelType *acf = ANIM_channel_get_typeinfo(ale);
@@ -352,7 +352,7 @@ static short acf_generic_group_offset(bAnimContext *ac, bAnimListElem *ale)
     }
   }
 
   /* offset is just the normal type - i.e. based on indention */
   return offset;
 }
 
@@ -530,10 +530,10 @@ static bAnimChannelType ACF_SUMMARY = {
     "Summary",              /* type name */
     ACHANNEL_ROLE_EXPANDER, /* role */
 
-    acf_summary_color,       /* backdrop color */
-    acf_summary_backdrop,    /* backdrop */
-    acf_generic_indention_0, /* indent level */
-    NULL,                    /* offset */
+    acf_summary_color,         /* backdrop color */
+    acf_summary_backdrop,      /* backdrop */
+    acf_generic_indentation_0, /* indent level */
+    NULL,                      /* offset */
 
     acf_summary_name, /* name */
     NULL,             /* name prop */
@@ -641,7 +641,7 @@ static bAnimChannelType ACF_SCENE = {
 
     acf_generic_root_color,    /* backdrop color */
     acf_generic_root_backdrop, /* backdrop */
-    acf_generic_indention_0,   /* indent level */
+    acf_generic_indentation_0, /* indent level */
     NULL,                      /* offset */
 
     acf_generic_idblock_name,      /* name */
@@ -817,7 +817,7 @@ static bAnimChannelType ACF_OBJECT = {
 
     acf_generic_root_color,    /* backdrop color */
     acf_generic_root_backdrop, /* backdrop */
-    acf_generic_indention_0,   /* indent level */
+    acf_generic_indentation_0, /* indent level */
     NULL,                      /* offset */
 
     acf_object_name,      /* name */
@@ -992,10 +992,10 @@ static bAnimChannelType ACF_GROUP = {
     "Group",               /* type name */
     ACHANNEL_ROLE_CHANNEL, /* role */
 
-    acf_group_color,          /* backdrop color */
-    acf_group_backdrop,       /* backdrop */
-    acf_generic_indention_0,  /* indent level */
-    acf_generic_group_offset, /* offset */
+    acf_group_color,           /* backdrop color */
+    acf_group_backdrop,        /* backdrop */
+    acf_generic_indentation_0, /* indent level */
+    acf_generic_group_offset,  /* offset */
 
     acf_group_name,      /* name */
     acf_group_name_prop, /* name prop */
@@ -1118,7 +1118,7 @@ static bAnimChannelType ACF_FCURVE = {
 
     acf_generic_channel_color,    /* backdrop color */
     acf_generic_channel_backdrop, /* backdrop */
-    acf_generic_indention_flexible,
+    acf_generic_indentation_flexible,
     /* indent level */        /* XXX rename this to f-curves only? */
     acf_generic_group_offset, /* offset */
 
@@ -1238,7 +1238,7 @@ static bAnimChannelType ACF_NLACONTROLS = {
 
     acf_nla_controls_color,    /* backdrop color */
     acf_nla_controls_backdrop, /* backdrop */
-    acf_generic_indention_0,   /* indent level */
+    acf_generic_indentation_0, /* indent level */
     acf_generic_group_offset,  /* offset */
 
     acf_nla_controls_name, /* name */
@@ -1278,7 +1278,7 @@ static bAnimChannelType ACF_NLACURVE = {
 
     acf_generic_channel_color,    /* backdrop color */
     acf_generic_channel_backdrop, /* backdrop */
-    acf_generic_indention_1,      /* indent level */
+    acf_generic_indentation_1,    /* indent level */
     acf_generic_group_offset,     /* offset */
 
     acf_nla_curve_name,   /* name */
@@ -1368,7 +1368,7 @@ static bAnimChannelType ACF_FILLACTD = {
 
     acf_generic_dataexpand_color,    /* backdrop color */
     acf_generic_dataexpand_backdrop, /* backdrop */
-    acf_generic_indention_1,         /* indent level */
+    acf_generic_indentation_1,       /* indent level */
     acf_generic_basic_offset,        /* offset */
 
     acf_generic_idblock_name,     /* name */
@@ -1453,7 +1453,7 @@ static bAnimChannelType ACF_FILLDRIVERS = {
 
     acf_generic_dataexpand_color,    /* backdrop color */
     acf_generic_dataexpand_backdrop, /* backdrop */
-    acf_generic_indention_1,         /* indent level */
+    acf_generic_indentation_1,       /* indent level */
     acf_generic_basic_offset,        /* offset */
 
     acf_filldrivers_name, /* name */
@@ -1532,7 +1532,7 @@ static bAnimChannelType ACF_DSMAT = {
 
     acf_generic_dataexpand_color,    /* backdrop color */
     acf_generic_dataexpand_backdrop, /* backdrop */
-    acf_generic_indention_1,         /* indent level */
+    acf_generic_indentation_1,       /* indent level */
     acf_generic_basic_offset,        /* offset */
 
     acf_generic_idblock_name,      /* name */
@@ -1613,7 +1613,7 @@ static bAnimChannelType ACF_DSLIGHT = {
 
     acf_generic_dataexpand_color,    /* backdrop color */
     acf_gene

@@ Diff output truncated at 10240 characters. @@
@@ -203,7 +203,7 @@ static void acf_generic_channel_color(bAnimContext *ac, bAnimListElem *ale, floa
   }
   else {
-    /* FIXME: what happens when the indention is 1 greater than what it should be
+    /* FIXME: what happens when the indentation is 1 greater than what it should be
      * (due to grouping)? */
     int colOfs = 10 - 10 * indent;
@@ -252,44 +252,44 @@ static void acf_generic_channel_backdrop(bAnimContext *ac,
   short indent = 0;
 
-  /* grouped F-Curves need extra level of indention */
+  /* grouped F-Curves need extra level of indentation */
   if (ale->type == ANIMTYPE_FCURVE) {
     FCurve *fcu = (FCurve *)ale->data;
@@ -252,44 +252,44 @@ static void acf_generic_channel_backdrop(bAnimContext *ac,
     FCurve *fcu = (FCurve *)ale->data;
 
-    /* TODO: we need some way of specifying that the indention color should be one less. */
+    /* TODO: we need some way of specifying that the indentation color should be one less. */
     if (fcu->grp) {
       indent++;
@@ -252,44 +252,44 @@ static void acf_generic_channel_backdrop(bAnimContext *ac,
 }
 
-/* basic offset for channels derived from indention */
+/* basic offset for channels derived from indentation */
 static short acf_generic_basic_offset(bAnimContext *ac, bAnimListElem *ale)
 {
@@ -352,7 +352,7 @@ static short acf_generic_group_offset(bAnimContext *ac, bAnimListElem *ale)
   }
 
-  /* offset is just the normal type - i.e. based on indention */
+  /* offset is just the normal type - i.e. based on indentation */
   return offset;
 }



More information about the Bf-blender-cvs mailing list